==> haskell-unix-compat-0.7.4.1-45-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-compat
version:              0.7.4.1
visibility:           public
id:                   unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
key:                  unix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  67811daa2cec39bdc9fb5b26f73a673c
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.4.1-FrCbkIkHqC8LnfXFaiVUhh
include-dirs:         /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1/include
includes:             HsUnixCompat.h
depends:              base-4.18.2.1 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-unix-compat-0.7.4.1-46-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-unix-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unix-compat
version:              0.7.4.1
visibility:           public
id:                   unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
key:                  unix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
license:              BSD-3-Clause
maintainer:           https://github.com/haskell-pkg-janitors
author:
    Björn Bringert, Duncan Coutts, Jacob Stanley, Bryan O'\''Sullivan

homepage:             https://github.com/haskell-pkg-janitors/unix-compat
synopsis:             Portable POSIX-compatibility layer.
description:
    This package provides portable implementations of parts
    of the unix package. This package re-exports the unix
    package when available. When it isn'\''t available,
    portable implementations are used.

category:             System
abi:                  67c4138250dd8c5c9e20ec7df02dfa94
exposed:              True
exposed-modules:
    System.PosixCompat System.PosixCompat.Extensions
    System.PosixCompat.Files System.PosixCompat.Process
    System.PosixCompat.Temp System.PosixCompat.Time
    System.PosixCompat.Types System.PosixCompat.Unistd

import-dirs:          /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unix-compat
hs-libraries:         HSunix-compat-0.7.4.1-4zbVOVPfIKMI5a8vIMtFDq
include-dirs:         /usr/lib/ghc-9.6.6/site-local/unix-compat-0.7.4.1/include
includes:             HsUnixCompat.h
depends:              base-4.18.2.1 unix-2.8.4.0
haddock-interfaces:   /usr/share/doc/haskell-unix-compat/html/unix-compat.haddock
haddock-html:         /usr/share/doc/haskell-unix-compat/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
